# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u1B05',
            '\u1B06',
            '\u1B07',
            '\u1B08',
            '\u1B09',
            '\u1B0A',
            '\u1B0B',
            '\u1B0C',
            '\u1B0D',
            '\u1B0E',
            '\u1B0F',
            '\u1B10',
            '\u1B11',
            '\u1B12',
            ]

SouthVowelMap = [
                '\u1B0F\u02BD',
                '\u1B11\u02BD',
                ]

ModernVowelMap = [
                 '\u1B33\u1B42\u02BD',
                 '\u1B06\u02BD',
                 ]

SinhalaVowelMap = [
                  '\u1B33\u1B43\u02BD'
                  ]

VowelSignMap =  [
                '\u1B35',
                '\u1B36',
                '\u1B37',
                '\u1B38',
                '\u1B39',
                '\u1B3A',
                '\u1B3B',
                '\u1B3C',
                '\u1B3D',
                '\u1B3E',
                '\u1B3F',
                '\u1B40',
                '\u1B41',
                ]

SouthVowelSignMap = [
                    '\u1B3E\u02BD',
                    '\u1B40\u02BD',
                    ]

ModernVowelSignMap =[
                    '\u1B42',
                    '\u1B35\u02BD']

SinhalaVowelSignMap = [
                      '\u1B43'
                      ]

AyogavahaMap = [
               '\u1B01',
               '\u1B02',
               '\u1B04'
               ]

ViramaMap =  [
             '\u1B44'
             ]

ConsonantMap =  [
                '\u1B13',
                '\u1B14',
                '\u1B15',
                '\u1B16',
                '\u1B17',

                '\u1B18',
                '\u1B19',
                '\u1B1A',
                '\u1B1B',
                '\u1B1C',

                '\u1B1D',
                '\u1B1E',
                '\u1B1F',
                '\u1B20',
                '\u1B21',

                '\u1B22',
                '\u1B23',
                '\u1B24',
                '\u1B25',
                '\u1B26',

                '\u1B27',
                '\u1B28',
                '\u1B29',
                '\u1B2A',
                '\u1B2B',

                '\u1B2C',
                '\u1B2D',
                '\u1B2E',
                '\u1B2F',

                '\u1B30',
                '\u1B31',
                '\u1B32',
                '\u1B33'
                ]

SouthConsonantMap = [
                    '\u1B2E\u1B34',
                    '\u1B31\u1B34',
                    '\u1B2D\u1B34',
                    '\u1B26\u1B34'
                    ]

NuktaConsonantMap =  [
                     '\u1B13\u1B34',
                     '\u1B14\u1B34',
                     '\u1B15\u1B34',
                     '\u1B1A\u1B34',
                     '\u1B1F\u1B34',
                     '\u1B20\u1B34',
                     '\u1B27\u1B34',
                     '\u1B2C\u1B34'
                     ]

SinhalaConsonantMap =[
                     '\u1B01\u1B15\u02BD',
                     '\u1B01\u1B1A\u02BD',
                     '\u1B01\u1B1F\u02BD',
                     '\u1B01\u1B24\u02BD',
                     '\u1B01\u1B29\u02BD',
                      ]

uniqueCons = {
        'w': 'ᬯ᬴'
}

NuktaMap = [
           '\u1B34'
           ]

OmMap = [
        '\u1B12\u1B01'
        ]

SignMap =[
         '\u0027',
         '\u1B5E',
         '\u1B5F'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\u1B50',
             '\u1B51',
             '\u1B52',
             '\u1B53',
             '\u1B54',
             '\u1B55',
             '\u1B56',
             '\u1B57',
             '\u1B58',
             '\u1B59',
             ]
